# alternative-front-ends
Overview of alternative open source front-ends for popular internet platforms (e.g. YouTube, Twitter, etc.)

## Call to Action
- Do you know any other **free/open-source** projects that are not included in the overview yet? (front ends, alternatives to websites, apps, etc.)
- Just create an [issue](https://github.com/mendel5/alternative-front-ends/issues) and let me know. I'm always looking for new free/open-source projects to add.

## Contents
- [YouTube](#youtube)
- [YouTube Music](#youtube-music)
- [Twitter](#twitter)
- [Reddit](#reddit)
- [TikTok](#tiktok)
- [Imgur](#imgur)
- [Spotify](#spotify)
- [Apple Music](#apple-music)
- [Bandcamp](#bandcamp)
- [Twitch](#twitch)
- [Discord](#discord)
- [Google Search](#google-search)
- [Google Translate](#google-translate)
- [Facebook](#facebook)
- [Facebook Messenger](#facebook-messenger)
- [Mastodon](#mastodon)
- [Medium](#medium)
- [IMDb](#imdb)
- [Quora](#quora)
- [Reuters](#reuters)
- [Apple AirPlay](#apple-airplay)
- [Shazam](#shazam)
- [Hacker News](#hacker-news)
- [Telegram](#telegram)
- [Other services](#other-services)
- [Redirection](#redirection)
- [Related projects](#related-projects)
- [About this repository](#about-this-repository)

## Overview

### YouTube

- [Invidious](https://github.com/iv-org/invidious): Invidious is an alternative front-end to YouTube - Lightweight, no ads, no tracking, no JavaScript required
  - Home page: https://invidious.io
  - Invidious instances: https://docs.invidious.io/instances/
  - Invidious instances API: https://api.invidious.io
  - Installation guide for self-hosting: https://docs.invidious.io/installation/

- [Piped](https://github.com/TeamPiped/Piped): An alternative privacy-friendly YouTube frontend which is efficient by design - Lightweight, no ads, no tracking
  - Official instance: https://piped.video
  - Public instances: https://github.com/TeamPiped/Piped/wiki/Instances
  - Installation guide for self-hosting: https://github.com/TeamPiped/Documentation/blob/main/content/docs/self-hosting/index.md

- [Poketube](https://github.com/ashley0143/poketube): The privacy-friendly youtube front-end built with the InnerTube API
  - Official instance: [https://poketube.fun](https://poketube.fun)

- [CloudTube](https://git.sr.ht/~cadence/cloudtube): Alternative front-end for Invidious
  - Official instance: https://tube.cadence.moe
  - Installation guide for self-hosting: https://git.sr.ht/~cadence/tube-docs/tree/main/item/docs/cloudtube/Installing%20CloudTube.md

- [YouTube.js](https://github.com/LuanRT/YouTube.js): Full-featured wrapper around the Innertube API, which is what YouTube itself uses

- [FreeTube](https://github.com/FreeTubeApp/FreeTube): Open source YouTube desktop player for privacy on Windows, Mac and Linux
  - Official Instance: https://freetubeapp.io/

- [Invuedious](https://github.com/bocchilorenzo/invuedious): An alternative frontend for invidious built with vue.js
  - Official instance: https://bocchilorenzo.github.io/invuedious

- [Youtube-viewer](https://github.com/trizen/youtube-viewer): Lightweight YouTube client for Linux

- [pipe-viewer](https://github.com/trizen/pipe-viewer): A lightweight application (fork of straw-viewer) for searching and playing videos from YouTube.

- [Invidious-viewer](https://github.com/git-bruh/invidious-viewer): Python application to watch YouTube videos through the Invidious API, in the terminal (requires MPV player and libmpv.so, provided by Linux distro)

- [NewPipe](https://github.com/TeamNewPipe/NewPipe): A libre lightweight streaming front-end for Android

- [Youtube-dl](https://github.com/ytdl-org/youtube-dl): Command-line program to download videos from YouTube.com and other video sites

- [OpenVideoDownloader aka jely2002/youtube-dl-gui](https://github.com/jely2002/youtube-dl-gui): A cross-platform GUI for youtube-dl made in Electron and node.js

- [ytdl-gui](https://github.com/JaGoLi/ytdl-gui): A simple-to-use, cross-platform graphical interface for youtube-dl

- [Alltube](https://github.com/Rudloff/alltube): Web GUI for youtube-dl

- [Vividl](https://github.com/Bluegrams/Vividl): Modern Windows GUI for youtube-dl

- [Tartube](https://github.com/axcore/tartube): A GUI front-end for youtube-dl, partly based on youtube-dl-gui and written in Python 3 / Gtk 3

- [ytmdl](https://github.com/deepjyoti30/ytmdl): A simple app to get songs from YouTube in mp3 format with artist name, album name etc from sources like iTunes, LastFM, Deezer, Gaana etc.

- [Plumber](https://github.com/keshavbhatt/plumber): Local and remote video trimmer, can trim parts of video without downloading whole video, utilizes youtube-dl, allows conversion to GIFs

- [ViewTube](https://github.com/ViewTube/viewtube-vue): An alternative front-end for YouTube, written in Vue.js, uses Plyr video player; supports SponsorBlock, multiple Invidious instances support, chapters

- [youtube-local](https://github.com/user234683/youtube-local): Browser-based client for watching Youtube anonymously and with greater page performance

- [yt-local](https://git.sr.ht/~heckyel/yt-local): Browser-based client for watching Youtube anonymously without forcing javascript (Fork of [youtube-local](https://github.com/user234683/youtube-local))

- [SkyTube](https://github.com/SkyTubeTeam/SkyTube): An open-source YouTube app for Android

- [yt-dlp](https://github.com/yt-dlp/yt-dlp): A youtube-dl fork with additional features and fixes

- [uYouPlus](https://github.com/qnblackcat/uYouPlus): uYouPlus (uYou+) is an alternative YouTube app for Apple's iOS and iPadOS

- [SmartTubeNext](https://github.com/yuliskov/SmartTubeNext): SmartTubeNext is an advanced YouTube app for Android TVs and TV boxes, free and open source. It is not a live TV client and does not support "YouTube TV"

- [TubeSync](https://github.com/meeb/tubesync): TubeSync is a PVR (personal video recorder) for YouTube. It syncs YouTube channels and playlists to a locally hosted media server

- [TubeArchivist](https://github.com/tubearchivist/tubearchivist): A self hosted YouTube media server

- [ytfzf](https://github.com/pystardust/ytfzf): A POSIX script that helps you find Youtube videos (without API) and opens/downloads them using mpv/youtube-dl

- [ytcc](https://github.com/woefe/ytcc): Command line tool to keep track of your favorite playlists on YouTube and many other places. Can import youtube subscriptions from Google Takeout and provide them as an RSS feed for your favorite reader

- [smtube](https://github.com/smplayer-dev/smtube): Stand-alone YouTube video player
  - Website: https://www.smtube.org
  - SMTube is part of SMPlayer
  - SMPlayer website: https://www.smplayer.info
  - SMPlayer repository: https://github.com/smplayer-dev/smplayer

- [mps-youtube](https://github.com/mps-youtube/mps-youtube): Terminal based YouTube player and downloader

- [minitube](https://github.com/flaviotordini/minitube): Lightweight youtube client with a kid-friendly interface. Can make playlists from search keywords

- [yattee](https://github.com/yattee/yattee): Alternative YouTube frontend for iOS, tvOS and macOS built with Invidious and Piped, supports sponsorblock

- [ytcast](https://github.com/MarcoLucidi01/ytcast): Cast YouTube videos to your smart TV from the command line. This program does roughly the same thing as the "Play on TV" button that appears on the player bar when you visit youtube.com with Chrome or when you use the YouTube smartphone app

- [LibreTube](https://github.com/libre-tube/LibreTube): Android frontend for YouTube, based on Piped

- [BlackHole](https://github.com/Sangwan5688/BlackHole): Android music player app for YouTube Music and Spotify made with Flutter

- [oleksis/youtube-dl-gui](https://github.com/oleksis/youtube-dl-gui): Cross-platform front-end GUI of the popular youtube-dl written in wxPython

### YouTube Music

- [ytmdesktop](https://github.com/ytmdesktop/ytmdesktop): Cross-platform (Windows, Mac, and Linux) desktop app for YouTube Music. Has a (proprietary?) remote control app for Android

- [Beatbump](https://github.com/snuffyDev/Beatbump): An alternative frontend for YouTube Music created using Svelte/SvelteKit, powered by Cloudflare Workers
  - Official instance: https://beatbump.ml/

- [AudioTube](https://invent.kde.org/plasma-mobile/audiotube): Client for YouTube Music. Plasma-mobile project with an interface designed for Linux phones

- [th-ch/youtube-music](https://github.com/th-ch/youtube-music): YouTube Music desktop app based on Electron bundled with custom plugins (including built-in ad blocker and downloader)

### Twitter

- [Nitter](https://github.com/zedeus/nitter): Alternative Twitter front-end - Lightweight, no ads, no tracking, no JavaScript required
  - Official instance: [nitter.net](https://nitter.net)
  - Public instances: https://github.com/zedeus/nitter/wiki/Instances
  - Example: Troy Hunt on [Twitter](https://twitter.com/troyhunt) and [Nitter](https://nitter.net/troyhunt)

- [Shitter](https://github.com/nuclearfog/Shitter): Android, alternative front-end for Twitter, built with Java

- [Harpy](https://github.com/robertodoering/harpy): Android, alternative front-end for Twitter, built with Flutter/Dart

- [Twidere X](https://github.com/TwidereProject/TwidereX-Android): Android, alternative front-end for Twitter, built mostly with Kotlin, in early stage

- [Tweeterr](https://github.com/sherwyn11/Tweeterr): A tool to use Twitter from the command line on the fly

- [Tweet-app](https://github.com/rhysd/tweet-app): Desktop Twitter client only for tweeting. Timeline never shows up

- [Tweepy](https://github.com/tweepy/tweepy): Twitter for Python

- [Fritter](https://github.com/jonjomckay/fritter): A free, open-source Twitter client for Android

### Reddit

- [Teddit](https://codeberg.org/teddit/teddit): Alternative Reddit front-end focused on privacy - Lightweight, no ads, no JavaScript, unofficial API
  - Official instance: https://teddit.net
  - Public instances: https://github.com/teddit-net/teddit#instances
  - [Github mirror repository](https://github.com/teddit-net/teddit)
  - Example: /r/Privacy on [Reddit](https://www.reddit.com/r/privacy) and [Teddit](https://teddit.net/r/privacy)

- [Libreddit](https://github.com/libreddit/libreddit): Alternative front-end for Reddit. Themed around Reddit's new design - Lightweight, no JavaScript, no ads, no tracking
  - Public instances: https://github.com/libreddit/libreddit-instances/blob/master/instances.md

- [Xeddit](https://github.com/ErlingMK/Xeddit): A Xamarin.Forms app for Reddit
  - Official instance: [xeddit.com](https://www.xeddit.com)
  - Example: /r/Privacy on [Reddit](https://www.reddit.com/r/privacy) and [Xeddit](https://www.xeddit.com/r/privacy)

- [RedditClient](https://github.com/grey-r/RedditSharp): Alternative front-end for Reddit, built with Angular

- [Updoot](https://github.com/adityam49/Updoot): Android, alternative front-end for Reddit

- [Eddrit](https://github.com/corenting/eddrit): Alternative front-end for Reddit, inspired by Nitter, built with Python & Starlette

- [Top of Reddit](https://github.com/mgerb/top-of-reddit): Top Reddit posts every day

- [Snew](https://github.com/snew/snew): Open-source client for Reddit forked from the Reddit source code

- [Stealth](https://gitlab.com/cosmosapps/stealth): Account-free, privacy-oriented, and feature-rich Reddit client
  - Available on [F-Droid](https://f-droid.org/en/packages/com.cosmos.unreddit)

- [Infinity](https://github.com/Docile-Alligator/Infinity-For-Reddit): Reddit client for Android
  - Available on [F-Droid](https://f-droid.org/en/packages/ml.docilealligator.infinityforreddit)

- [Dawn](https://github.com/Tunous/Dawn): Open-source Reddit app
  - Available on [F-Droid](https://f-droid.org/en/packages/me.thanel.dank)
  - Forked from Dank: https://github.com/saket/Dank

- [Slide](https://github.com/ccrama/Slide): Open source, ad free Reddit browser for Android
  - Available on [F-Droid](https://f-droid.org/en/packages/me.ccrama.redditslide)

- [junipf/reddit-frontend](https://github.com/junipf/reddit-frontend): A reddit front-end written in React
  - Official instance: https://jpf-reddit.netlify.app
  
- [kddit](https://git.kalli.st/kallist/kddit-spaghetti): uWSGI frontend for Reddit.com written in Python
  - Official instance: https://kddit.kalli.st

- [Troddit](https://github.com/burhan-syed/troddit): A web client for Reddit
  - Official instance: https://www.troddit.com

- [Roffline](https://github.com/Darkle/Roffline): A self-hosted offline Reddit server. It allows you to browse Reddit posts (including any media in the post) while offline. It is targeted at people that have intermittent internet

### TikTok

- [ProxiTok](https://github.com/pablouser1/ProxiTok): Open source alternative frontend for TikTok made with PHP
  - Official instance: https://proxitok.pabloferreiro.es/

### Imgur

- [Rimgo](https://codeberg.org/video-prize-ranch/rimgo): Self-hosted frontend for Imgur ritten in Go
  - Public instances: https://codeberg.org/video-prize-ranch/rimgo#instances

- [Rimgu](https://codeberg.org/3np/rimgu): Self-hosted alternative frontend/ proxy for Imgur

- [Imgin](https://git.voidnet.tech/kev/imgin): Minimal Imgur front end
  - Official instance: https://imgin.voidnet.tech
  - Example album on Imgur.com: https://imgur.com/a/GD6p5Fi
  - Same album on Imgin: https://imgin.voidnet.tech/a/GD6p5Fi

- [Omgur](https://github.com/geraldwuhoo/omgur): Omgur is a free and open-source alternative Imgur front-end focused on privacy. Inspired by the Invidious, Nitter, and Teddit projects.
  - No JavaScript or ads
  - All requests go through the Omgur backend, client never talks to Imgur
  - Prevents Imgur from tracking your IP or JavaScript fingerprint
  - Lightweight
  - Self-hostable

- [imgrs](https://github.com/geraldwuhoo/imgrs): Imgrs is a free and open-source alternative Imgur front-end focused on privacy. It's a Rust rewrite of a previous Imgur proxy project, Omgur.

### Spotify

- [psst](https://github.com/jpochyla/psst): Fast and multi-platform Spotify client with native GUI

- [Spotiqueue](https://github.com/toothbrush/Spotiqueue): Minimalistic queue-oriented macOS-native client for Spotify, with Guile Scheme scriptability

- [spot](https://github.com/xou816/spot): Gtk/Rust native Spotify client for the GNOME desktop. Only works with premium accounts

- [spotube](https://github.com/KRTirtho/spotube): A lightweight and free Spotify crossplatform-client which handles playback manually, streams music using Youtube & no Spotify premium account is needed

- [SpotX](https://github.com/amd64fox/SpotX): Modified Spotify Client for Windows (Windows Only) - Blocking ads and updates for the desktop version of Spotify, disabling podcasts and more

- [kotify](https://github.com/dzirbel/kotify): Requires Spotify Account - Multiplatform desktop client for Spotify focused on library organization for power users. Relies on official Spotify client for playback

- [librespot](https://github.com/librespot-org/librespot): Requires Spotify Premium Account - librespot is an open source client library for Spotify. It enables applications to use Spotify's service to control and play music via various backends, and to act as a Spotify Connect receiver. It is an alternative to the official and now deprecated closed-source libspotify. Additionally, it will provide extra features which are not available in the official library

- [spotifyd](https://github.com/Spotifyd/spotifyd): unix daemon, using librespot.

### Apple Music

- [Cider](https://github.com/ciderapp/Cider): Cross-platform Apple Music experience based on Electron and Vue.js written from scratch with performance in mind

### Bandcamp

- [Tent](https://codeberg.org/sun/Tent): A simple alternative front-end for Bandcamp that does not require JavaScript and proxies all requests

### Twitch

- [streamlink-twitch-gui](https://github.com/streamlink/streamlink-twitch-gui): Multi platform Twitch.tv browser for Streamlink

- [Twire](https://github.com/twireapp/Twire): Alternative and open source Twitch client for Android

- [Xtra](https://github.com/crackededed/Xtra): Twitch player and browser for Android

- [ElectronPlayer](https://github.com/oscartbeaumont/ElectronPlayer): Electron Based Web Video Services Player. Supports Netflix, Youtube, Twitch, Floatplane, Hulu and more

### Discord

- [gtkcord4](https://github.com/diamondburned/gtkcord4): A lightweight Discord client written in Golang which uses GTK3 for the user interface
- [openasar](https://github.com/GooseMod/OpenAsar): An open-source alternative of Discord desktop's app.asar

### Google Search

- [Whoogle Search](https://github.com/benbusby/whoogle-search): A self-hosted, ad-free, privacy-respecting metasearch engine for Google
  - Public instances: https://github.com/benbusby/whoogle-search#public-instances

- [Searx](https://github.com/searx/searx): Searx is a free privacy-respecting internet metasearch engine which aggregates results from more than 70 search services. Users are neither tracked nor profiled. Additionally, searx can be used over Tor for online anonymity
  - Public instances: https://searx.space

- [SearXNG](https://github.com/searxng/searxng): SearXNG is a free internet metasearch engine which aggregates results from various search services and databases. Users are neither tracked nor profiled (SearXNG is a fork of searx)

- [LibreX](https://github.com/hnhx/librex): Privacy respecting free meta search engine (free as in freedom)
  - Small and simple meta search engine, fetches and anonymizes results from Google only, has API support, allows redirects to Invidious/ Bibliogram/ Nitter/ Libreddit

### Google Translate

- [Lingva Translate](https://github.com/TheDavidDelta/lingva-translate): Alternative front-end for Google Translate, serving as a free and open-source translator with over a hundred languages available
  - Official instance: [lingva.ml](https://lingva.ml)
  - Public instances: https://github.com/TheDavidDelta/lingva-translate#instances

- [SimplyTranslate](https://codeberg.org/SimpleWeb/SimplyTranslate-Web): Provide fast and private translations to the user without wasting much overhead for extensive styling or JavaScript. Supports Google Translate, DeepL, ICIBA and LibreTranslate.
  - Home page and public instances: https://simple-web.org/projects/simplytranslate.html

- [SimplyTranslate Mobile](https://github.com/ManeraKai/simplytranslate_mobile): Unofficial Android client of SimplyTranslate.
  - Available on [F-Droid](https://f-droid.org/en/packages/com.simplytranslate_mobile)

- [InstaLate](https://gitlab.com/concept1tech/instalate): Distraction-free translation for Android, to be used directly from within any app. Supports Beolingus, DeepL, Dict.cc, GNU CIDE, Heinzelnisse, LibreTranslate, Linguee, WikDict and Wiktionary.
  - Available on [F-Droid](https://f-droid.org/en/packages/com.concept1tech.instalate)

- [DeepL Android](https://github.com/sakusaku3939/DeepLAndroid): Unofficial Android client for DeepL
  - Available on [F-Droid](https://f-droid.org/en/packages/com.example.deeplviewer)

- [Crow Translate](https://github.com/crow-translate/crow-translate): Simple and lightweight cross-platform translator that allows translation using LibreTranslate, Lingva, Google, Bing, and Yandex, as well as text-to-speech using Google

### Facebook

- [SlimSocial](https://github.com/rignaneseleo/SlimSocial-for-Facebook): Android, alternative front-end for Facebook, built with Java

- [Frost](https://github.com/AllanWang/Frost-for-Facebook): An extensive and functional third party app for Facebook (Android app)

### Facebook Messenger

- [Caprine](https://github.com/sindresorhus/caprine): Unofficial and privacy-focused Facebook Messenger app with many useful features

### Mastodon

- [Sengi](https://github.com/NicolasConstant/sengi): cross-platform multi-account Mastodon & Pleroma desktop client

- [TheDesk](https://github.com/cutls/TheDesk): cross-platform Mastodon & Misskey desktop client

- [Tootle](https://gitlab.gnome.org/World/tootle): simple GTK-based Linux Mastodon client

- [Tusky](https://github.com/tuskyapp/Tusky): lightweight Android Mastodon client

- [Fedilab](https://codeberg.org/tom79/Fedilab): multi-account Android Mastodon client

- [Pinafore](https://github.com/nolanlawson/pinafore): Alternative web client for Mastodon, focused on speed and simplicity **[Unmaintained](https://nolanlawson.com/2023/01/09/retiring-pinafore/)**

- [Hyperspace](https://github.com/hyperspacedev/hyperspace): cross-platform Mastodon client for the fediverse written in TypeScript and React **[In maintenance mode](https://github.com/hyperspacedev/hyperspace/issues/232)** 

### Medium

- [Scribe](https://sr.ht/~edwardloveall/Scribe): Alternative front-end to Medium.com
  - Official website: https://scribe.rip

- [Libmedium](https://github.com/realaravinth/libmedium): Alternative front-end to Medium.com
  - Official website: https://libmedium.batsense.net

### IMDb

- [libremdb](https://github.com/zyachel/libremdb): A FOSS alternative front-end to IMDb.
  - Official instance: https://libremdb.iket.me/
  - Public Instances: https://github.com/zyachel/libremdb#instances

### Quora

- [Quetre](https://github.com/zyachel/quetre): A libre front-end for Quora
  - Official website: https://quetre.iket.me/
  - Public instances: https://github.com/zyachel/quetre#instances

### Reuters

- [Neuters](https://github.com/HookedBehemoth/neuters): An alternative front-end to Reuters.com. It is intented to be lightweight and fast, and was heavily inspired by Nitter
  - Official instance: https://neuters.de

### Apple AirPlay

- [RPiPlay](https://github.com/FD-/RPiPlay): An open-source AirPlay mirroring server for the Raspberry Pi. Supports iOS 9 and up.

- [air-pi-play](https://github.com/rahul-thakoor/air-pi-play): Turn a Raspberry Pi into an Airplay server using RPiPlay to enable screen mirroring on tvs, monitors and projectors.

### Shazam

- [SongRec](https://github.com/marin-m/SongRec): Open-source Shazam client for Linux, written in Rust

### Telegram

- [Telegram-FOSS](https://github.com/Telegram-FOSS-Team/Telegram-FOSS): Unofficial, FOSS-friendly fork of the original Telegram client for Android

### Hacker News

- [HN-search](https://github.com/algolia/hn-search): Algolia Hacker News search
  - Example: [Highest rated submissions of the past 24 hours](https://hn.algolia.com/?sort=byPopularity&page=0&dateRange=last24h&type=all)

- [HNTopLinks](https://github.com/eguller/hntoplinks): Top Links on Hacker News

- [Hackerweb](https://github.com/cheeaun/hackerweb): A simply readable Hacker News web app
  - Official instance: https://hackerweb.app
  - About Hackerweb: https://hackerwebapp.com

- [Hckrnws](https://github.com/rajatkulkarni95/hckrnws): A custom front-end for a better reading experience of HackerNews
  - Official instance: https://www.hckrnws.com

- [Hackers](https://github.com/weiran/Hackers): a native iOS app for Hacker News
  - Available to download on the Apple AppStore: https://apps.apple.com/us/app/hackers-for-hacker-news/id603503901

### Other services

- [Pastewin](https://github.com/beucismis/pastewin): Free alternative Pastebin front-end

- [MediathekViewWeb](https://github.com/mediathekview/mediathekviewweb): Video content of German public-service television broadcasters (e.g. ARD, ZDF)
  - Official instance: [mediathekviewweb.de](https://mediathekviewweb.de)

- [NoPaste](https://github.com/bokub/nopaste): NoPaste is an open-source website similar to Pastebin where you can store any piece of code, and generate links for easy sharing

- [PrivateBin](https://github.com/PrivateBin/PrivateBin): Zero knowledge encrypted paste-bin. A minimalist, open source online pastebin where the server has zero knowledge of pasted data. Data is encrypted/decrypted in the browser using 256 bits AES

- [vaultwarden](https://github.com/dani-garcia/vaultwarden): Password manager. Unofficial Bitwarden compatible server written in Rust, formerly known as bitwarden_rs

- [snapdrop](https://github.com/RobinLinus/snapdrop): Similar to Apple's Airdrop but in your browser. A Progressive Web App for local file sharing

- [hedgedoc](https://github.com/hedgedoc/hedgedoc): Collaborative markdown editor. A platform to write and share markdown

- [etherpad-lite](https://github.com/ether/etherpad-lite): Collaborative rich text editor. A modern really-real-time collaborative document editor

- [gitea](https://github.com/go-gitea/gitea): Lightweight git server. Git with a cup of tea, painless self-hosted git service

- [ArchiveBox](https://github.com/ArchiveBox/ArchiveBox): Open source self-hosted web archiving. Takes URLs/browser history/bookmarks/Pocket/Pinboard/etc., saves HTML, JS, PDFs, media, and more

- [Wikiless](https://github.com/Metastem/wikiless): A free open source alternative Wikipedia front-end focused on privacy
  - Official instance: https://wikiless.org/
  - Public instances: https://github.com/Metastem/wikiless

- [Librarian](https://codeberg.org/librarian/librarian): Alternative frontend for LBRY / Odysee.com
  - Public instances: https://codeberg.org/librarian/librarian#instances

## Redirection

- [Privacy Redirect](https://github.com/SimonBrazell/privacy-redirect): A simple web extension that redirects Twitter, YouTube, & Google Maps requests to privacy friendly alternatives
  - [Firefox Add-On: Privacy Redirect](https://addons.mozilla.org/en-US/firefox/addon/privacy-redirect)
  - [Chrome Extension: Privacy Redirect](https://chrome.google.com/webstore/detail/privacy-redirect/pmcmeagblkinmogikoikkdjiligflglb)

- [libredirect](https://github.com/libredirect/libredirect): A web extension that redirects popular sites to alternative privacy-friendly frontends and backends. Actively maintained fork of Privacy Redirect that supports Youtube, Youtube Music, Twitter, TikTok, Imgur, Reddit, Searx, Google Translate, Google Maps, Wikipedia, and Medium
  - [Firefox Add-On](https://addons.mozilla.org/firefox/addon/libredirect/)
  - [Chrome Extension](https://libredirect.github.io/download_chromium.html)

- [Farside](https://github.com/benbusby/farside): Farside provides links that automatically redirect to working instances of privacy-oriented alternative frontends, such as Nitter, Libreddit, etc. This allows for users to have more reliable access to the available public instances for a particular service, while also helping to distribute traffic more evenly across all instances and avoid performance bottlenecks and rate-limiting.

- [UntrackMe](https://framagit.org/tom79/nitterizeme): UntrackMe transforms Twitter, YouTube, Reddit and Medium and Wikipedia links to links of open source, privacy friendly front-ends. Converts Google Maps links to OpenStreetMap links. Removes tracking parameters from any url. Then delegates the action to other apps that are capable of handling them. (Android app)

- [Redirector](https://github.com/einaregilsson/Redirector): Web browser extension (Firefox, Vivaldi, Chrome, Opera, Edge) to redirect URLs based on regex or wildcard patterns.
  - [Firefox Add-On: Redirector](https://addons.mozilla.org/firefox/addon/redirector/)
  - [Chrome Extension: Redirector](https://chrome.google.com/webstore/detail/redirector/ocgpenflpmgnfapjedencafcfakcekcd)

## Related projects

- [uBlock Origin](https://github.com/gorhill/uBlock): An efficient blocker for Chromium and Firefox. Fast and lean
  - [Firefox Add-On: uBlock Origin](https://addons.mozilla.org/en-US/firefox/addon/ublock-origin)
  - [Chrome Extension: uBlock Origin](https://chrome.google.com/webstore/detail/ublock-origin/cjpalhdlnbpafiamejdnhcphjbkeiagm)

- [StreetComplete](https://github.com/streetcomplete/StreetComplete): Easy to use OpenStreetMap editor for Android

- [Matrix.org's Synapse](https://github.com/matrix-org/synapse): End-to-end-encrypted messaging. Matrix reference homeserver. See also [matrix.org](https://matrix.org).

- [Pluja's Awesome Privacy](https://github.com/pluja/awesome-privacy): A curated list of services and alternatives that respect your privacy because privacy matters.

- [12ft.io / 12ft Ladder](https://12ft.io): 12ft Ladder is a free service for reading news articles. Prepend 12ft.io/ to the URL of any paywalled page, and we'll try our best to remove the paywall and get you access to the article. It is similar to Outline.com which is not available anymore.
  - Note: The source code of 12ft Ladder is not available under a free/open-source license.

- [Youtube Vanced](https://github.com/YTVanced): Youtube replacement app for the Android platform: YouTube Vanced is the stock Android YouTube app, but better. It includes adblocking, true amoled dark mode and a lot more. Use the Vanced Manager to install YouTube Vanced with ease.
  - Official website with install instructions: https://vancedapp.com
  - Note: The source code of Youtube Vanced is not available under a free/open-source license.
  - For an explanation about the origin of Youtube Vanced see here: https://old.reddit.com/r/Vanced/comments/o3xm9m/if_youtube_vanced_isnt_open_source_and_doesnt/h2ec7wf/
  - Vanced was forced to shut down by Google due to legal reasons. The project https://github.com/revanced tries to continue its legacy

## About this repository

This overview originally included three alternative front-ends: Invidious (for YouTube), Bibliogram (for Instagram) and Nitter (for Twitter). Therefore it was named `alternative front-ends`. As more projects have been added to the repository, the listed projects partially left the scope of *alternative front-ends*.

For example, `youtube-dl` is not a front-end, but can be generally described as an open source project that interacts with the internet platform Youtube.

Therefore the name `alternative front-ends` does not capture the full scope of the listed projects anymore. Maybe this repository will be renamed in the future to better reflect the larger scope. A possible name might be `open-source-alternatives` or something similar.
